use Lingua::Romana::Perligata
# 'converte',
# 'discribe'
# 'investiga',
;

maximum tum val inquementum tum biguttam tum stadium egresso scribe.
vestibulo perlegementum da meo maximo .
maximum tum novumversum egresso scribe.
da II tum maximum conscribementa meis listis.
dum damentum nexto listis decapitamentum fac sic
       lista sic hoc tum nextum recidementum  cis vannementa da listis.
       dictum sic deinde cis tum biguttam tum stadium tum cum nextum comementum tum novumversum scribe egresso.
    cis
